@@ -13,10 +13,18 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_dlm.literals import (
+    EventSourceValues,
+    EventTypeValues,
+    GettablePolicyStateValues,
+    IntervalUnitValues,
+    LocationValues,
+    PolicyTypeValues,
+    ResourceLocationValues,
+    ResourceTypeValues,
+    RetentionIntervalUnitValues,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -54,9 +62,9 @@ ActionTypeDef = TypedDict(
 CreateRuleTypeDef = TypedDict(
     "CreateRuleTypeDef",
     {
-        "Location": Literal["CLOUD", "OUTPOST_LOCAL"],
+        "Location": LocationValues,
         "Interval": int,
-        "IntervalUnit": Literal["HOURS"],
+        "IntervalUnit": IntervalUnitValues,
         "Times": List[str],
         "CronExpression": str,
     },
@@ -82,7 +90,7 @@ class CrossRegionCopyActionTypeDef(
 
 CrossRegionCopyRetainRuleTypeDef = TypedDict(
     "CrossRegionCopyRetainRuleTypeDef",
-    {"Interval": int, "IntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
+    {"Interval": int, "IntervalUnit": RetentionIntervalUnitValues},
     total=False,
 )
 
@@ -124,12 +132,10 @@ class EncryptionConfigurationTypeDef(
 
 EventParametersTypeDef = TypedDict(
     "EventParametersTypeDef",
-    {"EventType": Literal["shareSnapshot"], "SnapshotOwner": List[str], "DescriptionRegex": str},
+    {"EventType": EventTypeValues, "SnapshotOwner": List[str], "DescriptionRegex": str},
 )
 
-_RequiredEventSourceTypeDef = TypedDict(
-    "_RequiredEventSourceTypeDef", {"Type": Literal["MANAGED_CWE"]}
-)
+_RequiredEventSourceTypeDef = TypedDict("_RequiredEventSourceTypeDef", {"Type": EventSourceValues})
 _OptionalEventSourceTypeDef = TypedDict(
     "_OptionalEventSourceTypeDef", {"Parameters": "EventParametersTypeDef"}, total=False
 )
@@ -144,7 +150,7 @@ _RequiredFastRestoreRuleTypeDef = TypedDict(
 )
 _OptionalFastRestoreRuleTypeDef = TypedDict(
     "_OptionalFastRestoreRuleTypeDef",
-    {"Count": int, "Interval": int, "IntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
+    {"Count": int, "Interval": int, "IntervalUnit": RetentionIntervalUnitValues},
     total=False,
 )
 
@@ -158,9 +164,9 @@ LifecyclePolicySummaryTypeDef = TypedDict(
     {
         "PolicyId": str,
         "Description": str,
-        "State": Literal["ENABLED", "DISABLED", "ERROR"],
+        "State": GettablePolicyStateValues,
         "Tags": Dict[str, str],
-        "PolicyType": Literal["EBS_SNAPSHOT_MANAGEMENT", "IMAGE_MANAGEMENT", "EVENT_BASED_POLICY"],
+        "PolicyType": PolicyTypeValues,
     },
     total=False,
 )
@@ -170,7 +176,7 @@ LifecyclePolicyTypeDef = TypedDict(
     {
         "PolicyId": str,
         "Description": str,
-        "State": Literal["ENABLED", "DISABLED", "ERROR"],
+        "State": GettablePolicyStateValues,
         "StatusMessage": str,
         "ExecutionRoleArn": str,
         "DateCreated": datetime,
@@ -189,9 +195,9 @@ ParametersTypeDef = TypedDict(
 PolicyDetailsTypeDef = TypedDict(
     "PolicyDetailsTypeDef",
     {
-        "PolicyType": Literal["EBS_SNAPSHOT_MANAGEMENT", "IMAGE_MANAGEMENT", "EVENT_BASED_POLICY"],
-        "ResourceTypes": List[Literal["VOLUME", "INSTANCE"]],
-        "ResourceLocations": List[Literal["CLOUD", "OUTPOST"]],
+        "PolicyType": PolicyTypeValues,
+        "ResourceTypes": List[ResourceTypeValues],
+        "ResourceLocations": List[ResourceLocationValues],
         "TargetTags": List["TagTypeDef"],
         "Schedules": List["ScheduleTypeDef"],
         "Parameters": "ParametersTypeDef",
@@ -203,7 +209,7 @@ PolicyDetailsTypeDef = TypedDict(
 
 RetainRuleTypeDef = TypedDict(
     "RetainRuleTypeDef",
-    {"Count": int, "Interval": int, "IntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
+    {"Count": int, "Interval": int, "IntervalUnit": RetentionIntervalUnitValues},
     total=False,
 )
 
@@ -226,7 +232,7 @@ ScheduleTypeDef = TypedDict(
 _RequiredShareRuleTypeDef = TypedDict("_RequiredShareRuleTypeDef", {"TargetAccounts": List[str]})
 _OptionalShareRuleTypeDef = TypedDict(
     "_OptionalShareRuleTypeDef",
-    {"UnshareInterval": int, "UnshareIntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
+    {"UnshareInterval": int, "UnshareIntervalUnit": RetentionIntervalUnitValues},
     total=False,
 )
 
